/* -*- mode: c++; c-basic-offset: 3; -*- */
#ifndef GDS_FUNCTIONS_HH
#define GDS_FUNCTIONS_HH

/**  Greatest common denominator of two integers.
 */
long gcd(long a, long b);

/**  Greatest common denominator
 */
double gcd(double a, double b);

/**  Round a floating point number \a x up to the nearest integer multiple 
  *  of \a m that is not less than \a x. Zero is returned if either argument
  *  is less than or equal to zero.
  *  \brief Round a number up to and integer multiple of a specified value.
  *  \param x Number to be rounded.
  *  \param m Multiplier to be rounded to.
  *  \return Nearest multiple of \a m not less than \a x.
  */ 
double roundup(double x, double m);

/**  Round an integer \a x up to the nearest integer multiple 
  *  of \a m that is not less than \a x. The function is defined to be zero 
  *  if \a x is less than or equal to zero and \a x if m is less than or 
  *  equal to zero.
  *  \brief Round a number up to and integer multiple of a specified value.
  *  \param x Number to be rounded.
  *  \param m Multiplier to be rounded to.
  *  \return Nearest multiple of \a m not less than \a x.
  */ 
long iroundup(long x, long m);

#include "gds_functions.icc"

#endif // !defined(GDS_FUNCTIONS_HH)
